@@ -524,6 +524,12 @@ class Distributive(object):
             d['cl_profile_name'] = dv.Get('cl_profile_name')
             # make lazy call
             d['os_linux_files'] = partial(dv.Get, 'os_linux_files')
+            d['os_chrootable_set'] = "off"
+            try:
+                if process("/usr/bin/chroot", directory, "/bin/true").success():
+                    d['os_chrootable_set'] = "on"
+            except Exception:
+                pass
         except VariableError:
             pass
         return d.copy()
