@@ -543,7 +543,7 @@ class VariableClAutopartitionRootSize(SizeHelper, AutopartitionHelper,
         size = int(self.Get('cl_autopartition_root_size_default'))
         deviceSize = int(self.Get('cl_autopartition_device_size_all'))
         minRootSize = int(self.Get('cl_autopartition_root_size_min'))
-        if size >= deviceSize or self.use_rootall():
+        if self.use_rootall():
             size = max(deviceSize, minRootSize)
         return str(size)
 
