@@ -328,6 +328,9 @@ class VariableClImageFilename(DistroRepository, Variable):
                     imageData.get('os_linux_build', '') and
                         "os_arch_machine" in imageData):
             raise VariableError(_("Wrong image file"))
+        if imageData["os_chrootable_set"] == 'off':
+            raise VariableError(
+                _("The image is not compatible with the current kernel"))
 
     def humanImageName(self, distroinfo, filepath):
         if all(x in distroinfo for x in ("os_linux_shortname",
