@@ -765,13 +765,16 @@ class VariableOsGrub2Path(Variable):
 
     def get(self):
         # find grub2-install
-        grubInstall = getProgPath('/usr/sbin/grub2-install')
+        chroot_path = self.Get('cl_chroot_path')
+        chroot_cmd = getProgPath('/usr/bin/chroot')
+        grubInstall = getProgPath('/usr/sbin/grub2-install', prefix=chroot_path)
         if grubInstall:
             return grubInstall
         # find grub-install and check, that this is grub2-install (ver 1.99)
-        grubInstall = getProgPath('/usr/sbin/grub-install')
+        grubInstall = getProgPath('/usr/sbin/grub-install', prefix=chroot_path)
         if grubInstall and filter(lambda x: "1.99" in x or "2." in x,
-                                  process(grubInstall, '--version')):
+                                  process(chroot_cmd, chroot_path, 
+                                          grubInstall, '--version')):
             return grubInstall
         return ""
 
